@@ -7,9 +7,9 @@ class Func(object):
     sub_tasks: list
     workers: ThreadPoolExecutor
 
-    def __init__(self, fn, *, run_times: int = 1):
+    def __init__(self, fn, *, concurrent: int = 1):
         self.f: Callable = fn
-        self.thrds = run_times
+        self.thrds = concurrent
 
     def __len__(self):
         return len(self.sub_tasks)
@@ -35,29 +35,32 @@ class Func(object):
             self.workers = ThreadPoolExecutor(thrds)
             self.sub_tasks = [self.workers.submit(self.f, *args, **kwargs)
                               for _ in range(self.thrds)]
-            return block and [t.result() for t in self.sub_tasks] or self
-        raise Exception('run times is 0')
+            return block and self.result() or self
+        raise Exception('concurrent: 0')
 
     def wait(self, timeout=None):
         wait(self.sub_tasks, timeout=timeout)
 
     def result(self):
         res = [t.result() for t in self.sub_tasks]
-        return res[0] if len(res) == 1 else res
+        ret = res[0] if len(res) == 1 else res
+        return {self.f.__name__.upper(): ret}
 
     def cancel(self, shutdown=False):
         if hasattr(self, 'sub_tasks'):
-            [t.cancel() for t in self if not t.running()]
+            [t.cancel() for t in self if not (
+                    t.running() or t.done() or t.exception()
+            )]
         if hasattr(self, 'workers') and shutdown:
             self.workers.shutdown(wait=False)
 
 
-def repeat_wraps(fn=None, *, run_times=1, **default_args):
+def concurrent_wraps(fn=None, *, concurrent=1, **default_args):
     def wrap(f):
         @functools.wraps(f)
         def inner(*args, **kwargs):
             params = {**default_args, **kwargs}
-            return Func(f, run_times=run_times)(*args, **params)
+            return Func(f, concurrent=concurrent)(*args, **params)
 
         return inner
 
@@ -97,7 +100,7 @@ class Group(object):
             self.workers = ThreadPoolExecutor(concurrency)
             self.sub_tasks = [self.workers.submit(f) for f in self.group]
             return block and [t.result() for t in self.sub_tasks] or self
-        raise Exception('concurrency is 0')
+        raise Exception('concurrency: 0')
 
     @staticmethod
     def _f_wrap(f):
@@ -129,4 +132,4 @@ class Group(object):
             self.workers.shutdown(wait=False)
 
 
-__all__ = ('Func', 'repeat_wraps', 'Group')
+__all__ = ('Func', 'concurrent_wraps', 'Group')
